@@ -1,10 +1,18 @@
 from collections import OrderedDict
+from copy import deepcopy
 
 from django.conf import settings
 
-
 API_SRID = 4326
 
+_DEFAULT_MAP_STYLES = {
+    'detail': {'weight': 5, 'opacity': 1, 'color': 'yellow', 'arrowColor': '#FF5E00', 'arrowSize': 8},
+    'others': {'opacity': 0.9, 'fillOpacity': 0.7, 'color': 'yellow'},
+    'filelayer': {'color': 'red', 'opacity': 1.0, 'fillOpacity': 0.9, 'weight': 2, 'radius': 5},
+    'draw': {'color': '#35FF00', 'opacity': 0.8, 'weight': 3},
+    'print': {},
+}
+
 app_settings = dict({
     'TITLE': "",
     'HISTORY_ITEMS_MAX': 5,
@@ -20,6 +28,7 @@ app_settings = dict({
     'MAP_CAPTURE_SIZE': 800,
     'MAP_CAPTURE_MAX_RATIO': 1.25,
     'GEOM_FIELD_NAME': 'geom',
+    'GPX_FIELD_NAME': 'geom',
     'DATE_UPDATE_FIELD_NAME': 'date_update',
     'MAP_BACKGROUND_FOGGED': False,
     'MAP_FIT_MAX_ZOOM': 18,
@@ -32,8 +41,15 @@ app_settings = dict({
     'SENDFILE_HTTP_HEADER': None,
     'DRF_API_URL_PREFIX': r'^api/',
     'MAPENTITY_WEASYPRINT': False,
+    'MAP_STYLES': _DEFAULT_MAP_STYLES,
 }, **getattr(settings, 'MAPENTITY_CONFIG', {}))
 
+# default MAP_STYLES should not be replaced but updated by MAPENTITY_CONFIG
+_MAP_STYLES = deepcopy(_DEFAULT_MAP_STYLES)
+_MAP_STYLES.update(app_settings['MAP_STYLES'])
+app_settings['MAP_STYLES'] = _MAP_STYLES
+
+CRISPY_TEMPLATE_PACK = 'bootstrap4'
 
 TINYMCE_DEFAULT_CONFIG = {
     'theme': 'advanced',
@@ -70,21 +86,16 @@ REST_FRAMEWORK_DEFAULT_CONFIG = {
     'DEFAULT_RENDERER_CLASSES': [
         'rest_framework.renderers.JSONRenderer',
         'mapentity.renderers.GeoJSONRenderer',
-        'rest_framework.renderers.BrowsableAPIRenderer',
     ],
 }
 REST_FRAMEWORK_DEFAULT_CONFIG.update(getattr(settings, 'REST_FRAMEWORK', {}))
 setattr(settings, 'REST_FRAMEWORK', REST_FRAMEWORK_DEFAULT_CONFIG)
 
-
-_MAP_STYLES = {
-    'detail': {'weight': 5, 'opacity': 1, 'color': 'yellow', 'arrowColor': '#FF5E00', 'arrowSize': 8},
-    'others': {'opacity': 0.9, 'fillOpacity': 0.7, 'color': 'yellow'},
-    'filelayer': {'color': 'red', 'opacity': 1.0, 'fillOpacity': 0.9, 'weight': 2, 'radius': 5},
-    'draw': {'color': '#35FF00', 'opacity': 0.8, 'weight': 3},
-    'print': {},
-}
-
+for name, override in getattr(settings, 'MAP_STYLES', {}).items():
+    # fallback old settings MAP_STYLES
+    merged = app_settings['MAP_STYLES'].get(name, {})
+    merged.update(override)
+    app_settings['MAP_STYLES'][name] = merged
 
 _LEAFLET_PLUGINS = OrderedDict([
     ('leaflet.overintent', {
@@ -135,3 +146,10 @@ _LEAFLET_CONFIG = getattr(settings, 'LEAFLET_CONFIG', {})
 _LEAFLET_PLUGINS.update(_LEAFLET_CONFIG.get('PLUGINS', {}))  # mapentity plugins first
 _LEAFLET_CONFIG['PLUGINS'] = _LEAFLET_PLUGINS
 setattr(settings, 'LEAFLET_CONFIG', _LEAFLET_CONFIG)
+
+# MODELTRANSLATION config
+_MODELTRANSLATION_LANGUAGES = getattr(settings, 'MODELTRANSLATION_LANGUAGES', tuple(x[0] for x in settings.LANGUAGES))
+_MODELTRANSLATION_DEFAULT_LANGUAGE = getattr(settings, 'MODELTRANSLATION_DEFAULT_LANGUAGE',
+                                             _MODELTRANSLATION_LANGUAGES[0])
+setattr(settings, 'MODELTRANSLATION_LANGUAGES', _MODELTRANSLATION_LANGUAGES)
+setattr(settings, 'MODELTRANSLATION_DEFAULT_LANGUAGE', _MODELTRANSLATION_DEFAULT_LANGUAGE)
