@@ -1,24 +1,22 @@
-from __future__ import unicode_literals
-
 import json
 import logging
 import mimetypes
 import os
-from datetime import datetime
 import re
+from datetime import datetime
+from io import BytesIO
+from urllib.parse import quote
 
 from django.conf import settings
 from django.contrib.auth.decorators import login_required
 from django.contrib.gis.db.models import GeometryField
 from django.core.exceptions import PermissionDenied
-from django.urls import reverse
 from django.http import (HttpResponse, HttpResponseBadRequest, Http404)
 from django.shortcuts import get_object_or_404
-from django.utils.six.moves.urllib.parse import quote
+from django.urls import reverse
 from django.views import static
 from django.views.decorators.csrf import csrf_exempt
 from django.views.decorators.http import require_http_methods
-from django.views.defaults import page_not_found, permission_denied
 from django.views.generic.base import TemplateView
 from paperclip.settings import get_attachment_permission, get_attachment_model
 
@@ -26,19 +24,11 @@ from mapentity import models as mapentity_models
 from .mixins import JSONResponseMixin, FilterListMixin, ModelViewMixin
 from ..decorators import view_permission_required
 from ..helpers import capture_image
-from ..settings import app_settings, _MAP_STYLES
+from ..settings import app_settings
 
 logger = logging.getLogger(__name__)
 
 
-def handler403(request, template_name='mapentity/403.html'):
-    return permission_denied(request, template_name)
-
-
-def handler404(request, template_name='mapentity/404.html'):
-    return page_not_found(request, template_name)
-
-
 def serve_attachment(request, path):
     """
     Serve media/ for authorized users only, since it can contain sensitive
@@ -47,10 +37,10 @@ def serve_attachment(request, path):
     original_path = re.sub(r'\.\d+x\d+_q\d+(_crop)?\.(jpg|png|jpeg)$', '', path, count=1, flags=re.IGNORECASE)
     attachment = get_object_or_404(get_attachment_model(), attachment_file=original_path)
     obj = attachment.content_object
-    if not issubclass(obj._meta.model, mapentity_models.MapEntityMixin):
+    if not hasattr(obj._meta.model, 'attachments'):
         raise Http404
     if not obj.is_public():
-        if not request.user.is_authenticated():
+        if not request.user.is_authenticated:
             raise PermissionDenied
         if not request.user.has_perm(get_attachment_permission('read_attachment')):
             raise PermissionDenied
@@ -85,7 +75,7 @@ class JSSettings(JSONResponseMixin, TemplateView):
         dictsettings['debug'] = settings.DEBUG
         dictsettings['map'] = dict(
             extent=getattr(settings, 'LEAFLET_CONFIG', {}).get('SPATIAL_EXTENT'),
-            styles=_MAP_STYLES,
+            styles=app_settings['MAP_STYLES'],
         )
 
         # URLs
@@ -123,7 +113,7 @@ class BaseListView(FilterListMixin, ModelViewMixin):
     columns = None
 
     def __init__(self, *args, **kwargs):
-        super(BaseListView, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         if self.columns is None:
             # All model fields except geometries
@@ -135,7 +125,7 @@ class BaseListView(FilterListMixin, ModelViewMixin):
 
     @view_permission_required()
     def dispatch(self, *args, **kwargs):
-        return super(BaseListView, self).dispatch(*args, **kwargs)
+        return super().dispatch(*args, **kwargs)
 
 
 @csrf_exempt
@@ -170,8 +160,9 @@ def map_screenshot(request):
         width = context.get('viewport', {}).get('width')
         height = context.get('viewport', {}).get('height')
 
-        response = HttpResponse()
-        capture_image(map_url, response, width=width, height=height, selector=selector)
+        stream = BytesIO()
+        capture_image(map_url, stream, width=width, height=height, selector=selector)
+        response = HttpResponse(stream.getvalue(), content_type='image/png')
         response['Content-Disposition'] = 'attachment; filename=%s.png' % datetime.now().strftime('%Y%m%d-%H%M%S')
         return response
 
