@@ -1,6 +1,6 @@
-# -*- coding: utf-8 -*-
 import django_filters
 from django import forms
+
 from .generic import MapEntityList
 from ..filters import BaseMapEntityFilterSet
 from ..models import LogEntry
@@ -22,5 +22,5 @@ class LogEntryList(MapEntityList):
     columns = ('id', 'action_time', 'user', 'object', 'action_flag')
 
     def get_queryset(self):
-        queryset = super(LogEntryList, self).get_queryset()
+        queryset = super().get_queryset()
         return queryset.filter(content_type_id__in=registry.content_type_ids)
